==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActionNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventSet;
import io.ciera.tool.sql.ooaofooa.activity.ActionNode;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramActionSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.SendSignalSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptEventSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityDiagramActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.SendSignalSetImpl;

import java.util.Arrays;
import java.util.List;


public class ActionNodeSetImpl extends InstanceSet<ActionNodeSet,ActionNode> implements ActionNodeSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActionNode actionnode : this ) actionnode.setId( ref_Id );
    }


    // selections
    @Override
    public ActivityNodeSet R1105_is_a_ActivityNode() throws XtumlException {
        ActivityNodeSet activitynodeset = new ActivityNodeSetImpl();
        for ( ActionNode actionnode : this ) activitynodeset.add( actionnode.R1105_is_a_ActivityNode() );
        return activitynodeset;
    }
    @Override
    public AcceptEventSet R1107_is_a_AcceptEvent() throws XtumlException {
        AcceptEventSet accepteventset = new AcceptEventSetImpl();
        for ( ActionNode actionnode : this ) accepteventset.add( actionnode.R1107_is_a_AcceptEvent() );
        return accepteventset;
    }
    @Override
    public ActivityDiagramActionSet R1107_is_a_ActivityDiagramAction() throws XtumlException {
        ActivityDiagramActionSet activitydiagramactionset = new ActivityDiagramActionSetImpl();
        for ( ActionNode actionnode : this ) activitydiagramactionset.add( actionnode.R1107_is_a_ActivityDiagramAction() );
        return activitydiagramactionset;
    }
    @Override
    public SendSignalSet R1107_is_a_SendSignal() throws XtumlException {
        SendSignalSet sendsignalset = new SendSignalSetImpl();
        for ( ActionNode actionnode : this ) sendsignalset.add( actionnode.R1107_is_a_SendSignal() );
        return sendsignalset;
    }


    @Override
    public ActionNode nullElement() {
        return ActionNodeImpl.EMPTY_ACTIONNODE;
    }

    @Override
    public ActionNodeSet emptySet() {
      return new ActionNodeSetImpl();
    }

    @Override
    public ActionNodeSet value() {
        return this;
    }

    @Override
    public List<ActionNode> elements() {
        return Arrays.asList(toArray(new ActionNode[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActionNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventSet;
import io.ciera.tool.sql.ooaofooa.activity.ActionNode;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramActionSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.SendSignalSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptEventSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityDiagramActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.SendSignalSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ActionNodeSetImpl extends InstanceSet<ActionNodeSet,ActionNode> implements ActionNodeSet {

    public ActionNodeSetImpl() {
    }

    public ActionNodeSetImpl(Comparator<? super ActionNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActionNode actionnode : this ) actionnode.setId( ref_Id );
    }


    // selections
    @Override
    public ActivityNodeSet R1105_is_a_ActivityNode() throws XtumlException {
        ActivityNodeSet activitynodeset = new ActivityNodeSetImpl();
        for ( ActionNode actionnode : this ) activitynodeset.add( actionnode.R1105_is_a_ActivityNode() );
        return activitynodeset;
    }
    @Override
    public AcceptEventSet R1107_is_a_AcceptEvent() throws XtumlException {
        AcceptEventSet accepteventset = new AcceptEventSetImpl();
        for ( ActionNode actionnode : this ) accepteventset.add( actionnode.R1107_is_a_AcceptEvent() );
        return accepteventset;
    }
    @Override
    public ActivityDiagramActionSet R1107_is_a_ActivityDiagramAction() throws XtumlException {
        ActivityDiagramActionSet activitydiagramactionset = new ActivityDiagramActionSetImpl();
        for ( ActionNode actionnode : this ) activitydiagramactionset.add( actionnode.R1107_is_a_ActivityDiagramAction() );
        return activitydiagramactionset;
    }
    @Override
    public SendSignalSet R1107_is_a_SendSignal() throws XtumlException {
        SendSignalSet sendsignalset = new SendSignalSetImpl();
        for ( ActionNode actionnode : this ) sendsignalset.add( actionnode.R1107_is_a_SendSignal() );
        return sendsignalset;
    }


    @Override
    public ActionNode nullElement() {
        return ActionNodeImpl.EMPTY_ACTIONNODE;
    }

    @Override
    public ActionNodeSet emptySet() {
      return new ActionNodeSetImpl();
    }

    @Override
    public ActionNodeSet emptySet(Comparator<? super ActionNode> comp) {
      return new ActionNodeSetImpl(comp);
    }

    @Override
    public ActionNodeSet value() {
        return this;
    }

    @Override
    public List<ActionNode> elements() {
        return Arrays.asList(toArray(new ActionNode[0]));
    }

}
